

version 16
clear all
python clear
capture cd "$GoogleDriveWork"
capture cd "$GoogleDriveLaptop"
capture cd "$Presentations"
capture cd ".\Talks\AllTalks\27_IntroToPython\examples\"

// Define global macros for graph dimensions
global Width16x9  = 1920*2
global Height16x9 = 1080*2
global Width4x3   = 1440*2
global Height4x3  = 1080*2


// =============================================================================
//                       PREPARE STATA TO USE PYTHON
// =============================================================================

// Search for Python installations on the current system
python search

// Set which version of Python to use
// set python_exec C:\ProgramData\Anaconda3\python.exe

// Set user's additional module search paths
// set python_userpath  C:\ProgramData\Anaconda3\

// Query current Python settings and system information
python query

// Locate Python packages
python which numpy
python which requests
python which pandas
python which sklearn

// Install packages using PIP
//cd "C:\ProgramData\Anaconda3\pkgs\pip-19.2.3-py37_0\Scripts"
cd c:\ProgramData\Anaconda3\
shell conda install imageio
shell conda install mpl_toolkits
// If we were using regular Python (not Anaconda) we would type:
// cd c:\Python38
// shell pip install imageio
// shell pip install mpl_toolkits

// Download and install "ElementTree" for processing XML data
/*
local website "https://github.com/python/cpython/tree/3.8/Lib/xml/etree/ElementTree.py"
local mydrive "C:\ProgramData\Anaconda3\pkgs\pip-19.2.3-py37_0\Scripts/ElementTree.py"
cp `website' `mydrive' 
winexec pip install ///
    "C:\ProgramData\Anaconda3\pkgs\pip-19.2.3-py37_0\Scripts\xml.etree"

cp "https://github.com/python/cpython/tree/3.8/Lib/xml/etree/ElementTree.py" ///
   "C:\ProgramData\Anaconda3\pkgs\pip-19.2.3-py37_0\Scripts/ElementTree.py"
winexec pip install ///
    "C:\ProgramData\Anaconda3\pkgs\pip-19.2.3-py37_0\Scripts\xml.etree"    
*/
cd c:\ProgramData\Anaconda3\
shell conda install ElementTree
    

capture cd "$GoogleDriveWork"
capture cd "$GoogleDriveLaptop"
capture cd "$Presentations"
capture cd ".\Talks\AllTalks\27_IntroToPython\examples"

// Execute a single Python command
display "Hello Python, I am Stata"
python: "Hello Stata, I am Python"


// Call Python from within Stata
display "Hello Python, I am Stata"
python:
"Hello Stata, I am Python."
end

// Run a Python script from within Stata
display "Hello Python, I am Stata"
python script hello.py


// =============================================================================
//                       PASSING INFORMATION FROM Stata TO PYTHON
// =============================================================================

// Pass a local number from Stata to Python
local x = 2
python:
`x'
end

// Define a Python number from Stata local macro
local x = 2
python:
x = `x'
x
end

// Pass local numbers into Python 
// and perform a calculation
local x = 2
local y = 3
python:
z = `x'*`y'
z
end

/* Contents of the file product.py
import sys
arguments = sys.argv
print(arguments)
x = int(arguments[1])
y = int(arguments[2])
z = x*y
print(z)
*/
python script product.py, args(2 3) global

local x = 2
local y = 3
python script product.py, args(`x' `y') global


// Pass a local string into Python
local phrase "Hello World, why so blue?"
python:
"`phrase'"
end

// Assign the local string to a Python string
local phrase "Hello World, why so blue?"
python:
phrase_python = "`phrase'"
phrase_python
end

// List objects in the namespace of the __main__ module
python describe

// Drop objects from the namespace of the __main__ module
python drop phrase_python
python describe

// Clear objects from the namespace of the __main__ module
python clear

//python: import __main__
// python: __main__.normalpy("`depvar'","`indepvars'", "`touse'")
    
    

// Run Stata commands in Python
python:
stata: sysuse auto
stata: summarize mpg
end


// =============================================================================
//                  The Stata Function Interface (SFI)
// =============================================================================


// Use SFI to pass a local macro from Stata to Python
local name = "Bill"
python
from sfi import Macro
name = Macro.getLocal('name')
print(name)
end

// Use SFI to pass a local macro from Stata to Python
// and pass a string from Python to a local macro in Stata
local name = "Stata"
python
from sfi import Macro
name = Macro.getLocal('name')
hello = 'Hello ' + name + ', I am Python'
Macro.setLocal("hello", hello)
end
display "`hello'"


// Use SFI to pass a scalar from Stata to Python,
// perform a calculation, and pass the result 
// from Python to a scalar in Stata
scalar x = 5
python
from sfi import Scalar
x = Scalar.getValue('x')
x2 = x*x
x = Scalar.setValue("x2", x2)
end
display x2


// Use SFI to pass a matrix from Stata to Python,
// perform a calculation, and pass the result 
// from Python to a matrix in Stata
matrix X = (1,2\3,4)
matlist X
python
from sfi import Matrix
import numpy as np
X = Matrix.get('X')
X2 = np.dot(X,X)
x = Matrix.store("X2", X2)
end
matlist X2



// Pass a dataset from Stata to Python
sysuse auto, clear
list mpg weight in 1/5
python
from sfi import Data
data = Data.get('mpg weight', range(0,5))
print(data)
end


// Define a simple list
python:
# Define a simple list named beatles
beatles = ['John', 'Paul', 'George', 'Ringo']
print(beatles)
end


// Passing lists from Python to Stata
clear
python:
from sfi import Data

beatles = ['John', 'Paul', 'George', 'Ringo']

# Store the number of observations in the list
beatles_obs = len(beatles)

# Set the number of observations in Stata
Data.setObsTotal(beatles_obs)

# Create a variable in Stata the data
Data.addVarStr('beatles',20)

# Store the Python list to Stata
Data.store('beatles', None, beatles)
end

list




// Define a simple dictionary
python:
# Define a dictionary named beatles
beatles = {
    '1':'John',
    '2':'Paul',
    '3':'George',
    '4':'Ringo',
    }
print(beatles)
end


// Loop over values of a simple dictionary
python:
# Define a dictionary named beatles
beatles = {
    '1':'John',
    '2':'Paul',
    '3':'George',
    '4':'Ringo',
    }
    
for member in beatles.keys():
    print(beatles[member])
    
end  


// Convert the dictionary to a list
python:
# Define a dictionary named beatles
beatles = {
    '1':'John',
    '2':'Paul',
    '3':'George',
    '4':'Ringo',
    }
    
names = [beatles[member] for member in beatles.keys()]

print(names)
end 


// Passing dictionaries from Python to Stata
clear
python:
from sfi import Data
# Define a dictionary named beatles
beatles = {
    '1':'John',
    '2':'Paul',
    '3':'George',
    '4':'Ringo',
    }
# Convert the dictionary to a list
names = [beatles[member] for member in beatles.keys()]

# Write the list to Stata
beatles_obs = len(beatles)
Data.setObsTotal(beatles_obs)
Data.addVarStr('beatles',20)
Data.store('beatles', None, names)
end

list



// Convert a nested dictionary to a list
python:
from sfi import Data
# Define a nested dictionary named beatles
beatles = {
    '1':{'fname':'John', 'lname':'Lennon'},
    '2':{'fname':'Paul', 'lname':'McCartney'},
    '3':{'fname':'George', 'lname':'Harrison'},
    '4':{'fname':'Ringo', 'lname':'Starr'},
    }

fnames = [beatles[member]['fname'] for member in beatles.keys()]
lnames = [beatles[member]['lname'] for member in beatles.keys()]

print(fnames)
print(lnames)
end


// Passing nested dictionaries from Python to Stata
clear
python:
from sfi import Data
# Define a dictionary named beatles
beatles = {
    '1':{'fname':'John', 'lname':'Lennon'},
    '2':{'fname':'Paul', 'lname':'McCartney'},
    '3':{'fname':'George', 'lname':'Harrison'},
    '4':{'fname':'Ringo', 'lname':'Starr'},
    }

# Convert the dictionary to lists
fnames = [beatles[member]['fname'] for member in beatles.keys()]
lnames = [beatles[member]['lname'] for member in beatles.keys()]

# Write the list to Stata
beatles_obs = len(fnames)
Data.setObsTotal(beatles_obs)
Data.addVarStr('First',20)
Data.addVarStr('Last',20)
Data.store('First', None, fnames)
Data.store('Last', None, lnames)
end

list




// =============================================================================
//                               Functions
// =============================================================================

// Define a simple Python function
python:
def hello():
    print('Hello')

hello()    
end

// Pass an argument into a Python function
python:
def hello(name):
    print('Hello' + " " + name)

myname = 'Stata'
hello(myname)    
end

// Pass multiple arguments into a Python function
python:
def hello(fname,lname):
    print('Hello' + " " + fname + " " + lname)
myfname = 'Chuck'
mylname = 'Huber'
hello(myfname, mylname)    
end


// Call a Python function from Stata
python:
from sfi import Macro
import __main__
def hello(fname,lname):
    fname = Macro.getLocal('fname')
    lname = Macro.getLocal('lname')
    print('Hello' + " " + fname + " " + lname)
end

local fname "Chuck"
local lname "Huber"
python: __main__.hello("Chuck","Huber")



// Call a Python function from Stata
python:
from sfi import Matrix
from numpy.linalg import inv
import numpy as np
import __main__
def matreg(X,Y):
    X = Matrix.get('X')
    Y = Matrix.get('Y')
    XPXi = inv(np.dot(X,X))
    b = np.dot(XPXi,Y)
    x = Matrix.store("b", b)
end

matrix X = (1,2\3,4)
matrix Y = (5\6)
python: __main__.matreg('X','Y')
matlist b





// =============================================================================
//          Writing Stata Commands That Call Python Scripts and Functions
// =============================================================================


// Define a simple Stata command
capture program drop hello
program define hello
    display "Hello Python"
end

hello

// Use -syntax- to pass variables into the program
capture program drop varsin
program define varsin
    version 16
    syntax varlist(numeric)
    display "varlist = `varlist'"
end

sysuse auto, clear
varsin mpg weight foreign


// Use -gettoken- to parse "varlist"
capture program drop parsvars
program define parsvars
    version 16
    syntax varlist(numeric)
    gettoken depvar indepvars : varlist
    display "depvar = `depvar'"
    display "indepvars = `indepvars'"
end

sysuse auto, clear
parsvars mpg weight foreign


// Use -mkmat- to convert variables to matrices
capture program drop varstomat
program define varstomat
    version 16
    syntax varlist(numeric)
    gettoken depvar indepvars : varlist
    mkmat `depvar', matrix(Y)
    mkmat `indepvars', matrix(X)
end

sysuse auto, clear
keep in 1/5
list mpg weight foreign
varstomat mpg weight foreign
matlist X
matlist Y



// Use -mkmat- to convert variables to matrices
capture program drop varstopy
program define varstopy
    version 16
    syntax varlist(numeric)
    gettoken depvar indepvars : varlist
    clear matrix
    mkmat `depvar', matrix(Y)
    mkmat `indepvars', matrix(X)
    
    python script matregfunc.py
end

sysuse auto, clear
varstopy mpg weight foreign 
matlist b



// Write a Stata Command That Calls a Python Function
capture program drop varstopy
program define varstopy
    version 16
    syntax varlist(numeric)
    gettoken depvar indepvars : varlist
    clear matrix
    mkmat `depvar', matrix(Y)
    mkmat `indepvars', matrix(X)
    
    python script matregfunc.py
end

sysuse auto, clear
varstopy mpg weight foreign 
matlist b


// See the folder ./examples/regression/
python clear

do ./regression/pyregress1.ado
webuse nhanes2, clear
rename bpsystol sbp
pyregress1 sbp age weight

do ./regression/pyregress2.ado
webuse nhanes2, clear
rename bpsystol sbp
pyregress2 sbp age weight






/*
python:
from sfi import Matrix
from numpy.linalg import inv
import numpy as np
import __main__

def matreg(X,Y):
    X = Matrix.get('X')
    Y = Matrix.get('Y')
    XPXi = inv(np.dot(X,X))
    b = np.dot(XPXi,Y)
    x = Matrix.store("b", b)
end

matrix X = (1,2\3,4)
matrix Y = (5\6)
python: __main__.matreg('X','Y')
matlist b
*/






// =============================================================================
//                               Examples
// =============================================================================


// Fit a logistic regression model for -highbp- with a continuous-by-continuous
// interaction for age and weight.  Use -margins- to calculate marginal 
// predictions, and use Python to create a 3D marginsplot
// =======================================================
python clear
webuse nhanes2, clear
logistic highbp c.age##c.weight
quietly margins, at(age=(20(5)80) weight=(40(5)180)) saving(predictions, replace)
use predictions, clear
describe _at1 _at2 _margin
list _at1 _at2 _margin in 1/5

rename _at1 age
rename _at2 weight
rename _margin pr_HiSBP
list age weight pr_HiSBP in 1/5

#delimit ;
twoway 	(contour pr_HiSBP weight age, ccuts(0(0.1)1.0)), 	
	xlabel(20(10)80)									
	ylabel(40(20)180, angle(horizontal))
	xtitle("Age (years)")
	ytitle("Weight (kg)")
	ztitle("Predicted Probability of High SBP")
	title("Predicted Probability of High SBP by Age and Weight")
;
#delimit cr
graph export ./InteractContCont.png, as(png) width($Width4x3) height($Height4x3) replace



python:
import numpy as np
import matplotlib
matplotlib.use('TkAgg')
import matplotlib.pyplot as plt
from sfi import Data

# Use the sfi Data class to pull data from Stata variables into Python
X = np.array(Data.get("age weight pr_HiSBP"))

# Draw a graph in Python and save as marginsplot3d.png
ax = plt.axes(projection='3d')
plt.xticks(np.arange(20, 80, step=10))
plt.yticks(np.arange(40, 180, step=20))
ax.plot_trisurf(X[:, 0], X[:, 1], X[:, 2], cmap=plt.cm.Spectral_r, edgecolor='none')

ax.set_xlabel("Age (years)")
ax.set_ylabel("Weight (kg)")
ax.set_zlabel("P(High SBP)")
plt.savefig(".\..\graphs\marginsplot3d.png", dpi=1200)
end





// Run scripts to use API to get exchange rates for USA and UK
// ============================================================
//python script GetExchangeRate_today.py
//python script GetExchangeRate_date.py, args("2020-01-01") global

do ".\exchangerates\exrate.ado"

exrate
return list
display "Today's exchange rate for GBP to USD is `r(usd)'"





// Create a Stata command to display the current weather in Seattle
// https://rapidapi.com/theapiguy/api/national-weather-service/details
capture program drop weather
program weather
    version 16
    python script weather.py
    display "Current weather in Seattle:"
    display "`cloudy' and `temp' degrees"
end

weather






// Get data from the openFDA API and import into a Pandas data frame
// =================================================================

// Get and view the data from the openFDA API
// ------------------------------------------
python :
import requests
import json
import pandas as pd

URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200103]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'

data = requests.get(URL).json()

data
end


// Better view the raw data returned from the API
// ----------------------------------------------
python :
import requests
import json
import pandas as pd

URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200103]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'
data = requests.get(URL).json()

print(json.dumps(data, indent=2))
end



// get() the 'results' part of the data
// ------------------------------------
python :
import requests
import json
import pandas as pd

URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200103]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'
data = requests.get(URL).json()
#print(json.dumps(data, indent=2))

fdadata = data.get('results', [])
fdadata
end


// Convert the json data to a Pandas data frame
// --------------------------------------------
python :
import requests
import json
import pandas as pd

URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200110]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'
data = requests.get(URL).json()
#print(json.dumps(data, indent=2))
fdadata = data.get('results', [])

fda_df = pd.read_json(json.dumps(fdadata))
fda_df
end



// Convert the Pandas data frame to Stata using SFI
// ------------------------------------------------
clear
python :
import requests
import json
import pandas as pd
from sfi import Data, Macro

URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200110]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'
data = requests.get(URL).json()
#print(json.dumps(data, indent=2))
fdadata = data.get('results', [])

fda_df = pd.read_json(json.dumps(fdadata))
fda_df

time = fda_df["time"]
count = fda_df["count"]

#fda_df.ndim
rowcount = fda_df.shape[0]
rowcount
colcount = fda_df.shape[1]
colcount

Data.setObsTotal(rowcount)
#Data.addVarStr('date',20)
Data.addVarInt('date')
Data.addVarInt('count')
Data.store('date', None, time)
Data.store('count', None, count)
end
format %8.0f date
list





// Read data from a Stata dataset into a Pandas dataframe
// Then write the Pandas dataframe to a Stata dataset
// =============================================================================
sysuse auto, clear
keep mpg weight
keep in 1/5
list
save smallauto, replace

python:
import pandas as pd
smallauto = pd.read_stata('smallauto.dta')
smallauto
end

python:
import pandas as pd
smallauto
smallauto.to_stata('newsmallauto.dta', version=118)  
end
use newsmallauto, clear
list





// Convert a Pandas dataframe to a Stata dataset
// https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_stata.html
// ------------------------------------------------
python :
import requests
import json
import pandas as pd

URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200701]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'
data = requests.get(URL).json()
#print(json.dumps(data, indent=2))
fdadata = data.get('results', [])
fda_df = pd.read_json(json.dumps(fdadata))
fda_df

fda_df.to_stata('fentanyl.dta', version=118)  
end
use fentanyl.dta, clear





// Create a line plot of the Pandas data frame
// --------------------------------------------
python :
import requests
import json
import pandas as pd

URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200701]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'
data = requests.get(URL).json()
#print(json.dumps(data, indent=2))
fdadata = data.get('results', [])
fda_df = pd.read_json(json.dumps(fdadata))
fda_df

line = fda_df.plot.line(x='time', y='count')
line.figure.savefig("lineplot.png", dpi=2400)
end






// =============================================================================
//      Fentanyl adverse events and Johnson & Johnson's stock price
// =============================================================================
clear all
python clear

frame create fentanyl
frame create pricejnj

frame change fentanyl

// Convert a Pandas dataframe to a Stata dataset
// https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_stata.html
// ------------------------------------------------
// URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200701]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'

// Construct the API URL with Stata
local API     "https://api.fda.gov/drug/event.json?search="
local date    "receivedate:[20100101+TO+20200101]"
local country "occurcountry:"US""
local drug    "patient.drug.openfda.brand_name:"Fentanyl""
local data    "count=receivedate"

local URL "`API'`date'+AND+`country'+AND+`drug'&`data'"

python :
import requests
import json
import pandas as pd
from sfi import Macro

URL = Macro.getLocal('URL')
URL
# Submit the API data request
data = requests.get(URL).json()
# Extract the 'results' part of the JSON data
fdadata = data.get('results', [])
# Convert the JSON data to a Pandas data frame 
fda_df = pd.read_json(json.dumps(fdadata))
# Use Pandas to write the data frame to a Stata 16 dataset
fda_df.to_stata('fentanyl.dta', version=118)  
end
use fentanyl.dta, clear
drop index
gen date = mofd(date(string(time, "%8.0f"),"YMD"))
//format %tdCCYY-NN-DD date
//replace date = mofd(date)
format date %tm
collapse (sum) count, by(date)
tsset date, monthly



// Download stock price data for Johnson & Johnson from Yahoo Finance
// https://towardsdatascience.com/free-stock-data-for-python-using-yahoo-finance-api-9dafd96cad2e
// ----------------------------------------------------------------------------------------------

frame change pricejnj
python:
import yfinance as yf
import pandas as pd
rawdata = yf.download("JNJ", start="2010-01-01", end="2019-12-31")
dataframe = pd.DataFrame(data=rawdata)
dataframe = dataframe.rename(columns = {"Adj Close":"AdjClose"})
dataframe.to_stata('pricejnj.dta', version=118) 
end
use pricejnj, clear
gen date = mofd(dofc(Date))
format %tmCCYY!mNN date
collapse (mean) AdjClose, by(date)
tsset date, monthly


frlink 1:1 date, frame(fentanyl)
frget count, from(fentanyl)


#delimit ;
twoway (line AdjClose date, lcolor(blue) lwidth(medthick)) 
       (line count date, yaxis(2) lcolor(red) lwidth(medthick)), 
       ytitle(Johnson & Johnson Stock Price, color(blue)) 
       ylabel(, labcolor(blue) angle(horizontal)) 
       ytitle(Adverse Events Reported to the FDA, axis(2))  
       ytitle(, color(red) axis(2)) 
       ylabel(0(2000)10000, labcolor(red) angle(horizontal) axis(2)) 
       xtitle("") 
       title(Johnson & Johnson Stock Price and, size(medlarge)) 
       subtitle(Fentanyl Adverse Events Reported to the FDA, size(medlarge)) 
       caption(Data Source: openFDA, size(small) color(red)) 
       note(Data Source: Yahoo Finance, size(small) color(blue)) 
       legend(order(1 "Stock Price" 2 "Adverse Events") cols(1) position(11) ring(0))
       scheme(s1color)
;
#delimit cr
graph export ./graphs/StockPriceAdverseEvents.png, ///
             as(png) width($Width4x3) height($Height4x3) replace




             
             
             
             
// =============================================================================
//      Fentanyl adverse events and the S&P Pharmaceutical ETF price
// =============================================================================
clear all
python clear

frame create fentanyl
frame create pricepharma

frame change fentanyl

// Convert a Pandas dataframe to a Stata dataset
// https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_stata.html
// ------------------------------------------------
// URL = 'https://api.fda.gov/drug/event.json?search=receivedate:[20200101+TO+20200701]+AND+occurcountry:"US"+AND+patient.drug.openfda.brand_name:"Fentanyl"&count=receivedate'

// Construct the API URL with Stata
local API     "https://api.fda.gov/drug/event.json?search="
local date    "receivedate:[20100101+TO+20200101]"
local country "occurcountry:"US""
local drug    "patient.drug.openfda.brand_name:"Fentanyl""
local data    "count=receivedate"

local URL "`API'`date'+AND+`country'+AND+`drug'&`data'"

python :
import requests
import json
import pandas as pd
from sfi import Macro

URL = Macro.getLocal('URL')
URL
# Submit the API data request
data = requests.get(URL).json()
# Extract the 'results' part of the JSON data
fdadata = data.get('results', [])
# Convert the JSON data to a Pandas data frame 
fda_df = pd.read_json(json.dumps(fdadata))
# Use Pandas to write the data frame to a Stata 16 dataset
fda_df.to_stata('fentanyl.dta', version=118)  
end
use fentanyl.dta, clear
drop index
gen date = mofd(date(string(time, "%8.0f"),"YMD"))
format date %tm
collapse (sum) count, by(date)
tsset date, monthly



// Download price data for the S&P Pharmaceutical ETF from Yahoo Finance
// https://towardsdatascience.com/free-stock-data-for-python-using-yahoo-finance-api-9dafd96cad2e
// ----------------------------------------------------------------------------------------------
frame change pricepharma
python:
import yfinance as yf
import pandas as pd
rawdata = yf.download("XPH", start="2010-01-01", end="2019-12-31")
dataframe = pd.DataFrame(data=rawdata)
dataframe = dataframe.rename(columns = {"Adj Close":"AdjClose"})
dataframe.to_stata('pricepharma.dta', version=118) 
end

use pricepharma, clear
gen date = mofd(dofc(Date))
format %tmCCYY!mNN date
collapse (mean) AdjClose, by(date)
tsset date, monthly


frlink 1:1 date, frame(fentanyl)
frget count, from(fentanyl)

#delimit ;
twoway (line AdjClose date, lcolor(blue) lwidth(medthick)) 
       (line count date, yaxis(2) lcolor(red) lwidth(medthick)), 
       ytitle("S&P Pharmaceutical ETF Price", color(blue)) 
       ylabel(, labcolor(blue) angle(horizontal)) 
       ytitle(Adverse Events Reported to the FDA, axis(2))  
       ytitle(, color(red) axis(2)) 
       ylabel(0(2000)13000, labcolor(red) angle(horizontal) axis(2)) 
       xtitle("") 
       title("S&P Pharmaceutical ETF Price and", size(medlarge)) 
       subtitle(Fentanyl Adverse Events Reported to the FDA, size(medlarge)) 
       caption(Data Source: openFDA, size(small) color(red)) 
       note(Data Source: Yahoo Finance, size(small) color(blue)) 
       legend(order(1 "ETF Price" 2 "Adverse Events") cols(1) position(11) ring(0))
       scheme(s1color)
;
#delimit cr
graph export ./graphs/ETFPriceAdverseEvents.png, ///
             as(png) width($Width4x3) height($Height4x3) replace


             
             
             
             
// =============================================================================
//    Use Michael Droste's -pyforest- command for Random Forest classification 
// =============================================================================             
clear all
python clear             
webuse nhanes2
set seed 16
keep if hlthstat<5
// Generate a training flag, marking approx 30% of dataset as training
gen training = runiform()<0.75
// Run random forest classifier, training on training sample      
pyforest hlthstat age bmi bpsystol tcresult if training==1, type(classify)
// Save predictions out to variable hlthstat_predicted
predict hlthstat_predicted
tab hlthstat_predicted hlthstat
            
    
                 



